@@ -11,6 +11,8 @@ fn compare_bytes(actual: &[u8], expected: &[u8]) {
             panic!("Byte {} doesn't match: {} != {}", i, actual[i], expected[i]);
         }
     }
+
+    assert_eq!(actual.len(), expected.len());
 }
 
 struct TestCase {
@@ -77,9 +79,7 @@ fn encode() {
 #[test]
 fn header_magic() {
     assert!(matches!(
-        b"boif1234112341234123423412341234"
-            .qoi_decode_to_vec(None)
-            .unwrap_err(),
+        b"boif1234123412".qoi_decode_to_vec(None).unwrap_err(),
         QoiError::IncorrectHeaderMagic
     ));
 }
@@ -89,6 +89,6 @@ fn buffer_size_errors() {
     let mut buffer = Vec::new();
     buffer.resize(1024, 0);
 
-    let error = b"qoif".qoi_decode(None, &mut buffer).unwrap_err();
+    let error = b"qoif123412341".qoi_decode(None, &mut buffer).unwrap_err();
     assert!(matches!(error, QoiError::InputSmallerThanHeader));
 }
